@@ -1,8 +1,9 @@
-from .utils import router, render
+from .utils import router, render, path_reverse
 from .utils import ROUTES
 
 all = [
 	'router',
 	'render'
+	'path_reverse',
 	'ROUTES',
 ]
\ No newline at end of file
